@@ -2,7 +2,7 @@
 (* bdb_stubs.c - Stubs appropriate for Berkeley DB 4.x and DB 5.x      *)
 (*                                                                     *)
 (* Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, *)
-(*               2011, 2012  Yaron Minsky and Contributors             *)
+(*               2011, 2012, 2013  Yaron Minsky and Contributors       *)
 (*                                                                     *)
 (* This file is part of SKS.  SKS is free software; you can            *)
 (* redistribute it and/or modify it under the terms of the GNU General *)
