@@ -3,7 +3,7 @@
 (*               database queries.                                     *)
 (*                                                                     *)
 (* Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, *)
-(*               2011, 2012  Yaron Minsky and Contributors             *)
+(*               2011, 2012, 2013  Yaron Minsky and Contributors       *)
 (*                                                                     *)
 (* This file is part of SKS.  SKS is free software; you can            *)
 (* redistribute it and/or modify it under the terms of the GNU General *)
@@ -68,9 +68,18 @@ struct
       failwith "Running sks_db without transactions is no longer supported."
 
   let websocks =
-    List.map ~f:Eventloop.create_sock
+    List.rev_map ~f:Eventloop.maybe_create_sock
       ((if !Settings.use_port_80 then make_addr_list http_address 80 else [])
        @ make_addr_list http_address http_port)
+  let websocks =
+    List.fold_right ~init:[]
+      ~f:(function
+	   | Some sock -> fun acc -> sock :: acc
+	   | None -> fun acc -> acc)
+      websocks
+  let () =
+    if websocks = [] then
+      failwith "Could not listen on any address."
 
   let () =
     if Sys.file_exists db_command_name
@@ -257,7 +266,7 @@ struct
             ("text/html; charset=UTF-8",
              count,
              HtmlTemplates.page
-               ~title:(sprintf "Public Key Server -- Get ``%s ''"
+               ~title:(sprintf "Public Key Server -- Get \"%s \""
                          (String.concat ~sep:" " request.search))
                ~body:(sprintf "\r\n<pre>\r\n%s\r\n</pre>\r\n" aakeys)
             )
@@ -278,13 +287,17 @@ struct
             else key
           in
           let keystr = Key.to_string key in
-          let aakeys = Armor.encode_pubkey_string keystr in
-          ("text/html; charset=UTF-8",
-           1,
-           HtmlTemplates.page
-             ~title:(sprintf "Public Key Server -- Get ``%s ''" hash_str)
-             ~body:(sprintf "\r\n<pre>\r\n%s\r\n</pre>\r\n" aakeys)
-          )
+          let aakey = Armor.encode_pubkey_string keystr
+          in
+          if request.machine_readable then
+            ("application/pgp-keys; charset=UTF-8", 1, aakey)
+          else
+            ("text/html; charset=UTF-8",
+             1,
+             HtmlTemplates.page
+               ~title:(sprintf "Public Key Server -- Get ``%s ''" hash_str)
+               ~body:(sprintf "\r\n<pre>\r\n%s\r\n</pre>\r\n" aakey)
+            )
 
       | Index | VIndex ->
           (* VIndex requests are treated indentically to index requests *)
@@ -293,8 +306,8 @@ struct
           let keys = lookup_keys request.search in
           let count = List.length keys in
           let keys = truncate request.limit keys in
-          let hashes = List.map ~f:KeyHash.hash keys in
           let keys = clean_keys request keys in
+          let hashes = List.map ~f:KeyHash.hash keys in
           if request.machine_readable then
             ("text/plain",
              count,
