@@ -3,7 +3,7 @@
 (*                events                                               *)
 (*                                                                     *)
 (* Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, *)
-(*               2011, 2012  Yaron Minsky and Contributors             *)
+(*               2011, 2012, 2013  Yaron Minsky and Contributors       *)
 (*                                                                     *)
 (* This file is part of SKS.  SKS is free software; you can            *)
 (* redistribute it and/or modify it under the terms of the GNU General *)
@@ -131,6 +131,8 @@ let create_sock addr =
     let sock =
       socket ~domain ~kind:SOCK_STREAM ~protocol:0 in
     setsockopt sock SO_REUSEADDR true;
+    if domain = PF_INET6 then
+      setsockopt sock IPV6_ONLY true;
     bind sock ~addr;
     listen sock ~max:20;
     sock
@@ -143,6 +145,18 @@ let add_events heap evlist =
                   Heap.push heap ~key:time ~data:callback)
     evlist
 
+let maybe_create_sock addr =
+  try
+    Some (create_sock addr)
+  with
+    | err ->
+        let saddr = match addr with
+          | ADDR_UNIX path ->  "\"" ^ path ^ "\""
+          | ADDR_INET(ip, port) -> (string_of_inet_addr ip) ^ ":" ^ (string_of_int port)
+        in
+        perror "Failed to listen on %s: %s" saddr (err_to_string err);
+        None
+
 (***************************************************************)
 (*  Event Handlers  *******************************************)
 (***************************************************************)
