@@ -2,7 +2,7 @@
 (* htmlTemplates.ml                                                    *)
 (*                                                                     *)
 (* Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, *)
-(*               2011, 2012  Yaron Minsky and Contributors             *)
+(*               2011, 2012, 2013  Yaron Minsky and Contributors       *)
 (*                                                                     *)
 (* This file is part of SKS.  SKS is free software; you can            *)
 (* redistribute it and/or modify it under the terms of the GNU General *)
@@ -38,6 +38,8 @@ let html_quote string =
         | '>' -> sout#write_string "&gt;"
         | '&' -> sout#write_string "&amp;"
         | '"' -> sout#write_string "&quot;"
+        | '\''-> sout#write_string "&#x27;"
+        | '/'-> sout#write_string "&#x2F;"
         | c -> sout#write_char c
     done;
     ""
