@@ -3,7 +3,7 @@
 (*                                                                     *)
 (*                                                                     *)
 (* Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, *)
-(*               2011, 2012  Yaron Minsky and Contributors             *)
+(*               2011, 2012, 2013  Yaron Minsky and Contributors       *)
 (*                                                                     *)
 (* This file is part of SKS.  SKS is free software; you can            *)
 (* redistribute it and/or modify it under the terms of the GNU General *)
@@ -57,7 +57,7 @@ let for_all ~f:test array =
   Array.fold_left ~f:(fun a b -> a && (test b)) ~init:true array
 
 let exists ~f:test array =
-  Array.fold_left ~f:(fun a b -> a or (test b)) ~init:false array
+  Array.fold_left ~f:(fun a b -> a || (test b)) ~init:false array
 
 let mem el array =
   let length = Array.length array in
